@@ -24,12 +24,10 @@ OC.L10N.register(
     "Set due date" : "Stel sperdatum",
     "All day" : "Heeldag",
     "Task not found!" : "Taak nie gevind!",
-    "%s %% completed" : "%s %% voltooi",
     "Edit" : "Wysig",
     "Download" : "Laai Af",
     "Save" : "Stoor",
     "New List" : "Nuwe lys",
-    "The name \"%s\" is already used." : "Die naam “%s” bestaan reeds.",
     "An empty name is not allowed." : "’n Leë naam word nie toegestaan nie.",
     "Settings" : "Instellings",
     "Visibility of Smart Collections" : "Sigbaarheid van Slimversamelings",
