@@ -22,12 +22,10 @@ OC.L10N.register(
     "Set due date" : "Afitar la data de caducidá",
     "All day" : "Tol día",
     "Task not found!" : "¡Xera non atopada!",
-    "%s %% completed" : "%s %% completáu",
     "Edit" : "Editar",
     "Download" : "Baxar",
     "Save" : "Guardar",
     "New List" : "Nueva Llista",
-    "The name \"%s\" is already used." : "El nome \"%s\" yá ta usándose.",
     "An empty name is not allowed." : "Nun s'almite un nome baleru",
     "Settings" : "Axustes",
     "Visibility of Smart Collections" : "Visibilidá de Coleiciones Intelixentes",
