@@ -16,12 +16,10 @@ OC.L10N.register(
     "Set start date" : "Başlanğıc tarixini işə sal",
     "Set due date" : "Vaxtı təyin et",
     "Task not found!" : "Tapşırıq tapılmadı!",
-    "%s %% completed" : "%s %% bitmişdir",
     "Edit" : "Dəyişiklik et",
     "Download" : "Yüklə",
     "Save" : "Saxla",
     "New List" : "Yeni Siyahı",
-    "The name \"%s\" is already used." : "Ad \"%s\" artıq istifadə edilir.",
     "An empty name is not allowed." : "Boş ada izin verilmir.",
     "Visibility of Smart Collections" : "Ağıllı yiğımların görünməsi",
     "Hidden" : "Gizli",
