@@ -15,12 +15,10 @@ OC.L10N.register(
     "Tomorrow" : "আগামীকাল",
     "Set start date" : "আরম্ভের তারিখ নির্ধারণ করুন",
     "Set due date" : "কার্যকারিতার তারিখ নির্ধারণ করুন",
-    "%s %% completed" : "%s %% সুসম্পন্ন",
     "Edit" : "সম্পাদনা",
     "Download" : "ডাউনলোড",
     "Save" : "সংরক্ষণ",
     "New List" : "নতুন তালিকা",
-    "The name \"%s\" is already used." : "\"%s\" নামটি ইতোমধ্যে ব্যবহৃত হচ্ছে।",
     "An empty name is not allowed." : "একটি শুন্য নাম গ্রহণযোগ্য নয়।",
     "Visibility of Smart Collections" : "চটপট সংগ্রহের দর্শনযোগ্যতা",
     "Hidden" : "লুকনো",
