@@ -26,13 +26,10 @@ OC.L10N.register(
     "All day" : "Hele dagen",
     "Select a calendar" : "Vælg en kalender",
     "Task not found!" : "Opgaven blev ikke fundet!",
-    "%s %% completed" : "%s %% er fuldført",
-    "Created %s" : "Oprettede %s",
     "Edit" : "Redigér",
     "Download" : "Hent",
     "Save" : "Gem",
     "New List" : "Ny liste",
-    "The name \"%s\" is already used." : "Navnet \"%s\" er allerede i brug.",
     "An empty name is not allowed." : "Et tomt navn er ikke tilladt.",
     "Settings" : "Indstillinger",
     "Visibility of Smart Collections" : "Synlighed for smarte samlinger",
