@@ -23,12 +23,17 @@ OC.L10N.register(
     "Due date" : "Ημερομηνία λήξης",
     "Sort by due date and summary." : "Ταξινόμηση ανά ημερομηνία λήξης και σύνοψης.",
     "Start date" : "Ημερομηνία έναρξης",
+    "Sort by start date and summary." : "Ταξινόμηση ανά ημερομηνία έναρξης και σύνοψη.",
     "Created date" : "Ημερομηνία δημιουργίας",
+    "Sort by created date and summary." : "Ταξινόμηση κατά ημερομηνία και σύνοψη. ",
     "Last modified" : "Τελευταία τροποίηση",
+    "Sort by last-modified date and summary." : "Ταξινόμηση κατά ημερομηνία και σύνοψη τελευταίας τροποποίησης.",
     "Completed date" : "Ημερομηνία ολοκλήρωσης",
     "Priority" : "Προτεραιότητα",
     "Manually" : "Χειροκίνητα",
+    "Sort by manual order." : "Ταξινόμηση με χειροκίνητη σειρά.",
     "Alphabetically" : "Αλφαβητικά",
+    "Sort by summary and priority." : "Ταξινόμηση κατά σύνοψη και προτεραιότητα.",
     "Task is completed" : "Η εργασία ολοκληρώθηκε",
     "[Yesterday]" : "[Χθες]",
     "[Today]" : "[Σήμερα]",
@@ -46,10 +51,7 @@ OC.L10N.register(
     "Task not found!" : "Δεν βρέθηκε εργασία!",
     "[Due today]" : "[Λήγει σήμερα]",
     "[Due tomorrow]" : "[Λήγει αύριο]",
-    "%s %% completed" : "%s %% ολοκληρωμένες",
-    "Last modified %s" : "Τελευταία τροποποίηση %s",
-    "Created %s" : "Δημιουργήθηκε %s",
-    "Completed %s" : "Ολοκληρώθηκε %s",
+    "No priority assigned" : "Δεν έχει εκχωρηθεί προτεραιότητα",
     "Edit" : "Επεξεργασία",
     "Copy private link" : "Αντιγραφή ιδιωτικού συνδέσμου",
     "Copied" : "Αντιγράφηκε",
@@ -60,7 +62,6 @@ OC.L10N.register(
     "New List" : "Νέα λίστα",
     "Calendar link copied to clipboard." : "Ο σύνδεσμος του ημερολογίου αντιγράφηκε στο πρόχειρο.",
     "Calendar link could not be copied to clipboard." : "Αδυναμία αντιγραφής συνδέσμου ημερολογίου στο πρόχειρο.",
-    "The name \"%s\" is already used." : "Το όνομα \"%s\" χρησιμοποιείται ήδη.",
     "An empty name is not allowed." : "Δεν επιτρέπεται κενό όνομα.",
     "Settings" : "Ρυθμίσεις",
     "Default list" : "Προεπιλεγμένη λίστα",
@@ -72,6 +73,7 @@ OC.L10N.register(
     "Synchronizing to the server." : "Συγχρονισμός με τον διακομιστή.",
     "Task successfully saved to server." : "Η εργασία αποθηκεύτηκε επιτυχώς στον διακομιστή.",
     "Could not update the task." : "Αδυναμία ενημέρωσης της εργασίας.",
+    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discared." : "Δεν ήταν δυνατή η ενημέρωση της εργασίας επειδή άλλαξε στον διακομιστή. Κάντε κλικ για να την ανανεώσετε, οι τοπικές αλλαγές θα διαγραφούν.",
     "An error occurred" : "Παρουσιάστηκε σφάλμα"
 },
 "nplurals=2; plural=(n != 1);");
