@@ -23,12 +23,10 @@ OC.L10N.register(
     "Set due date" : "Establecer fecha de vencimiento",
     "All day" : "Todo el día",
     "Task not found!" : "¡Tarea no encontrada!",
-    "%s %% completed" : "%s %% terminado",
     "Edit" : "Editar",
     "Download" : "Descargar",
     "Save" : "Guardar",
     "New List" : "Nueva Lista",
-    "The name \"%s\" is already used." : "El nombre \"%s\" ya está en uso.",
     "An empty name is not allowed." : "No se permite un nombre vacío.",
     "Settings" : "Configuraciones ",
     "Visibility of Smart Collections" : "Visibilidad de Colecciones Inteligentes",
