@@ -24,12 +24,10 @@ OC.L10N.register(
     "Set due date" : "Määra tähtaeg",
     "All day" : "Kogu päev",
     "Task not found!" : "Ülesannet ei leitud!",
-    "%s %% completed" : "%s %% valmis",
     "Edit" : "Muuda",
     "Download" : "Lae alla",
     "Save" : "Salvesta",
     "New List" : "Uus nimekiri",
-    "The name \"%s\" is already used." : "Nimi \"%s\" on juba kasutuses.",
     "An empty name is not allowed." : "Nime lahter ei tohi olla tühi.",
     "Settings" : "Seaded",
     "Visibility of Smart Collections" : "Nutikate kollektsioonide nähtavus",
