@@ -21,14 +21,12 @@ OC.L10N.register(
     "Set start date" : "Ezarri hasteko eguna",
     "Set due date" : "Ezarri epemuga",
     "All day" : "Egun osoa",
-    "%s %% completed" : "%% %s  betea",
     "When shared show full event" : "Partekatzean erakutsi gertaera osoa",
     "When shared hide this event" : "Partekatzean ezkutatu gertaera hau",
     "Edit" : "Editatu",
     "Download" : "Deskargatu",
     "Save" : "Gorde",
     "New List" : "Zerrenda berria",
-    "The name \"%s\" is already used." : "\"%s\" izena dagoeneko erabilita dago.",
     "An empty name is not allowed." : "Hutsa ez da izentzat onartzen.",
     "Settings" : "Ezarpenak",
     "Visibility of Smart Collections" : "Bilduma argien ikusgarritasuna",
