@@ -20,8 +20,8 @@ OC.L10N.register(
     "Priority" : "Tärkeys",
     "Manually" : "Käsin",
     "Alphabetically" : "Aakkosjärjestys",
-    "{complete} % completed" : "{complete} % valmiina",
     "Task is completed" : "Tehtävä on valmis",
+    "{complete} % completed" : "{complete} % valmiina",
     "[Yesterday]" : "[Eilen]",
     "[Today]" : "[Tänään]",
     "[Tomorrow]" : "[Huomenna]",
@@ -34,9 +34,6 @@ OC.L10N.register(
     "Select categories" : "Valitse luokat",
     "Add this as a new category" : "Lisää tämä uutena luokkana",
     "Task not found!" : "Tehtävää ei löytynyt!",
-    "%s %% completed" : "%s %% valmiina",
-    "Last modified %s" : "Viimeksi muokattu %s",
-    "Created %s" : "Luotu %s",
     "Edit" : "Muokkaa",
     "Copy private link" : "Kopioi yksityinen linkki",
     "Copied" : "Kopioitu",
@@ -46,9 +43,7 @@ OC.L10N.register(
     "New List" : "Uusi luettelo",
     "Calendar link copied to clipboard." : "Kalenterilinkki kopioitu leikepöydälle.",
     "Calendar link could not be copied to clipboard." : "Kalenterilinkkiä ei voitu kopioida leikepöydälle.",
-    "The name \"%s\" is already used." : "Nimi \"%s\" on jo käytössä.",
     "An empty name is not allowed." : "Nimi ei voi olla tyhjä.",
-    "This will delete the calendar \"%s\" and all corresponding events and tasks." : "Tämä poistaa kalenterin \"%s\" ja kaikki sitä vastaavat tapahtumat sekä tehtävät.",
     "Settings" : "Asetukset",
     "Default list" : "Oletusluettelo",
     "Visibility of Smart Collections" : "Älykkäiden kokoelmien näkyvyys",
