@@ -30,10 +30,10 @@ OC.L10N.register(
     "Sort by manual order." : "מיון ידני.",
     "Alphabetically" : "בסדר האלף-בית",
     "Sort by summary and priority." : "מיון לפי תקציר ועדיפות.",
-    "{complete} % completed" : "{complete} % הושלמו",
     "Task is completed" : "המשימה הושלמה",
-    "Toggle visibility of all subtasks." : "החלפת מצב חשיפה של כל תת־המשימות.",
+    "{complete} % completed" : "{complete} % הושלמו",
     "Toggle visibility of completed subtasks." : "החלפת מצב חשיפה של כל תת־המשימות שהושלמו.",
+    "Toggle visibility of all subtasks." : "החלפת מצב חשיפה של כל תת־המשימות.",
     "[Yesterday]" : "[אתמול]",
     "[Today]" : "[היום]",
     "[Tomorrow]" : "[מחר]",
@@ -71,13 +71,6 @@ OC.L10N.register(
     "[Was due yesterday at] LT" : "[מועד התפוגה היה אתמול בשעה] LT",
     "[Was due on] LL [at] LT" : "[מועד התפוגה היה] LL [בשעה] LT",
     "No priority assigned" : "לא הוגדרה עדיפות",
-    "Priority %s: high" : "עדיפות %s: גבוהה",
-    "Priority %s: medium" : "עדיפות %s: בינונית",
-    "Priority %s: low" : "עדיפות %s: נמוכה",
-    "%s %% completed" : "%s %% הושלמו",
-    "Last modified %s" : "מועד שינוי אחרון %s",
-    "Created %s" : "יצירה %s",
-    "Completed %s" : "השלמה %s",
     "Edit" : "עריכה",
     "Copy private link" : "העתקת קישור פרטי",
     "Copied" : "הועתק",
@@ -87,9 +80,7 @@ OC.L10N.register(
     "New List" : "רשימה חדשה",
     "Calendar link copied to clipboard." : "הקישור ללוח השנה הועתק ללוח הגזירים.",
     "Calendar link could not be copied to clipboard." : "לא ניתן להעתיק את הקישור ללוח השנה אל לוח הגזירים.",
-    "The name \"%s\" is already used." : "השם \"%s\" כבר קיים.",
     "An empty name is not allowed." : "שדה שם ריק אינו מותר.",
-    "This will delete the calendar \"%s\" and all corresponding events and tasks." : "פעולה זו תמחק את לוח השנה „%s” ואת כל האירועים והמשימות הקשורים אליו.",
     "Settings" : "הגדרות",
     "Default list" : "רשימת בררת מחדל",
     "Visibility of Smart Collections" : "הצגה של אוספים חכמים",
