@@ -16,12 +16,10 @@ OC.L10N.register(
     "Tomorrow" : "Deman",
     "Set start date" : "Assigna le data de initio",
     "Set due date" : "Assignar data debite",
-    "%s %% completed" : "%s %% completate",
     "Edit" : "Modificar",
     "Download" : "Discargar",
     "Save" : "Salveguardar",
     "New List" : "Nove Lista",
-    "The name \"%s\" is already used." : "Le nomine \"%s\" ja es usate.",
     "An empty name is not allowed." : "Un nomine vacue non es permittite.",
     "Settings" : "Configurationes",
     "Visibility of Smart Collections" : "Visibilitate de Collectiones Intelligente",
