@@ -16,12 +16,10 @@ OC.L10N.register(
     "Set start date" : "Atur tanggal mulai",
     "Set due date" : "Atur tanggal jatuh tempo",
     "Task not found!" : "Tugas tidak ditemukan!",
-    "%s %% completed" : "%s %% selesai",
     "Edit" : "Sunting",
     "Download" : "Unduh",
     "Save" : "Simpan",
     "New List" : "Daftar Baru",
-    "The name \"%s\" is already used." : "Nama \"%s\" sudah digunakan.",
     "An empty name is not allowed." : "Nama kosong tidak diperbolehkan.",
     "Settings" : "Pengaturan",
     "Visibility of Smart Collections" : "Visibilitas Koleksi Cerdas",
