@@ -24,12 +24,10 @@ OC.L10N.register(
     "Set due date" : "განპირობებულია თარიღისთვის",
     "All day" : "მთელი დღე",
     "Task not found!" : "დაველბა ვერ იქნა ნაპოვნი!",
-    "%s %% completed" : "%s %% დასრულდა",
     "Edit" : "რედაქტირება",
     "Download" : "ჩამოტვირთვა",
     "Save" : "შენახვა",
     "New List" : "ახალი სია",
-    "The name \"%s\" is already used." : "სახელი \"%s\" უკვე დაკავებულია",
     "An empty name is not allowed." : "ცარიელი სახელი არაა ნებადართული",
     "Settings" : "პარამეტრები",
     "Visibility of Smart Collections" : "ჭკვიანი კოლექციების ხილვადობა",
