@@ -24,12 +24,10 @@ OC.L10N.register(
     "Set due date" : "만료 기한 설정",
     "All day" : "하루 종일",
     "Task not found!" : "작업을 찾을 수 없습니다!",
-    "%s %% completed" : "%s%% 완료됨",
     "Edit" : "편집",
     "Download" : "다운로드",
     "Save" : "저장",
     "New List" : "새 목록",
-    "The name \"%s\" is already used." : "이름 \"%s\"이(가) 이미 사용 중입니다.",
     "An empty name is not allowed." : "이름을 비워둘 수 없습니다.",
     "Settings" : "설정",
     "Visibility of Smart Collections" : "똑똑한 모음집 표시 여부",
