@@ -16,12 +16,10 @@ OC.L10N.register(
     "Set start date" : "Setz en Ufanks Datum fest",
     "Set due date" : "Datum setzen bis wéini et fälleg ass",
     "Task not found!" : "Tâche konnt net fonnt ginn!",
-    "%s %% completed" : "%s %% erfëllt",
     "Edit" : "Änneren",
     "Download" : "Eroflueden",
     "Save" : "Späicheren",
     "New List" : "Nei Lëscht",
-    "The name \"%s\" is already used." : "Den Numm \"%s\" gëtt scho gebraucht.",
     "An empty name is not allowed." : "En eidelen Numm ass net erlaabt.",
     "Settings" : "Astellungen",
     "Hidden" : "Verstoppt",
