@@ -24,12 +24,10 @@ OC.L10N.register(
     "Set due date" : "Uzstādīt izpildes termiņu",
     "All day" : "Visas dienas",
     "Task not found!" : "Uzdevums nav atrasts!",
-    "%s %% completed" : "%s %% izpildīti",
     "Edit" : "Rediģēt",
     "Download" : "Lejupielādēt",
     "Save" : "Saglabāt",
     "New List" : "Jauns saraksts",
-    "The name \"%s\" is already used." : "Nosaukums \"%s\" jau tiek lietots.",
     "An empty name is not allowed." : "Nosaukums ir obligāts.",
     "Settings" : "Iestatījumi",
     "Visibility of Smart Collections" : "Viedo kolekciju redzamība",
