@@ -16,12 +16,10 @@ OC.L10N.register(
     "Set start date" : "Especificar la data de començament",
     "Set due date" : "Especificar la data d'escasença",
     "Task not found!" : "Prètzfach pas trobat !",
-    "%s %% completed" : "completada a %s %%",
     "Edit" : "Modificar",
     "Download" : "Telecargar",
     "Save" : "Enregistrar",
     "New List" : "Novèla lista",
-    "The name \"%s\" is already used." : "Lo nom \"%s\" es ja utilizat.",
     "An empty name is not allowed." : "Un nom void es pas autorizat.",
     "Settings" : "Paramètres",
     "Visibility of Smart Collections" : "Visibilitat de las colleccions Smart",
