@@ -16,12 +16,10 @@ OC.L10N.register(
     "Set start date" : "Defina a data de inicio ",
     "Set due date" : "Definir data de expiração",
     "Task not found!" : "Tarefa não encontrada!",
-    "%s %% completed" : "%s %% completo",
     "Edit" : "Editar",
     "Download" : "Transferir",
     "Save" : "Guardar",
     "New List" : "Nova Lista",
-    "The name \"%s\" is already used." : "O nome \"%s\" já está a ser usado.",
     "An empty name is not allowed." : "Não é permitido um nome em branco.",
     "Settings" : "Definições",
     "Visibility of Smart Collections" : "Visibilidade das Coleções Inteligentes",
