@@ -16,12 +16,10 @@ OC.L10N.register(
     "Set start date" : "Setează data de început",
     "Set due date" : "Setează termenul limită",
     "Task not found!" : "Sarcina nu a fost găsită!",
-    "%s %% completed" : "%s %% efectuat",
     "Edit" : "Editează",
     "Download" : "Descarcă",
     "Save" : "Salvează",
     "New List" : "Listă nouă",
-    "The name \"%s\" is already used." : "Numele \"%s\" este deja folosit.",
     "An empty name is not allowed." : "Un nume vid nu este permis.",
     "Settings" : "Setări",
     "Visibility of Smart Collections" : "Vizibilitatea colecțiilor inteligente",
