@@ -32,15 +32,12 @@ OC.L10N.register(
     "Set due date" : "Nastaviť do dátumu",
     "All day" : "Celý deň",
     "Task not found!" : "Úloha nebola nájdená!",
-    "%s %% completed" : "%s %% ukončené",
     "Edit" : "Upraviť",
     "Download" : "Sťahovanie",
     "Save" : "Uložiť",
     "Add List…" : "Pridať zoznam",
     "New List" : "Nový zoznam",
-    "The name \"%s\" is already used." : "Názov \"%s\" je už použitý.",
     "An empty name is not allowed." : "Prázdny názov nie je povolený",
-    "This will delete the calendar \"%s\" and all corresponding events and tasks." : "Táto operácia odstráni kalendár \"%s\" a všetky jeho udalosti a úlohy.",
     "Settings" : "Nastavenia",
     "Visibility of Smart Collections" : "Viditeľnosť inteligentných kolekcií",
     "Hidden" : "Skryté",
