@@ -24,12 +24,10 @@ OC.L10N.register(
     "Set due date" : "Caktoni datë mbarimi",
     "All day" : "Gjithë ditën",
     "Task not found!" : "S’u gjet punë!",
-    "%s %% completed" : "%s %% e plotësuar",
     "Edit" : "Përpunoni",
     "Download" : "Shkarkoje",
     "Save" : "Ruaje",
     "New List" : "Listë e Re",
-    "The name \"%s\" is already used." : "Emri \"%s\" është tashmë në përdorim.",
     "An empty name is not allowed." : "Nuk lejohet emër i zbrazët.",
     "Settings" : "Rregullime",
     "Visibility of Smart Collections" : "Dukshmëri Koleksionesh të Mençura",
