@@ -19,8 +19,10 @@ OC.L10N.register(
     "Cancel" : "取消",
     "Delete all completed tasks." : "删除所有已完成任务。",
     "Delete completed tasks." : "删除已完成任务。",
+    "Deleted all completed tasks from calendar \"{calendar}\"." : "从日历 \"{calendar}\" 中删除所有已完成任务。",
     "No errors" : "没有错误",
     "Open your browser console for more details" : "打开您的浏览器控制台以获取更多详细信息",
+    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["此操作将从日历 \"{calendar}\" 中删除 {taskCount} 个已完成任务及其子任务。"],
     "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["无法删除 {failedCount} 个任务。"],
     "Load all completed tasks." : "载入所有已完成任务。",
     "Change sort order" : "更改排序",
@@ -49,7 +51,13 @@ OC.L10N.register(
     "[Yesterday]" : "[昨天]",
     "[Today]" : "[今天]",
     "[Tomorrow]" : "[明天]",
+    "Add a subtask to \"{task}\"…" : "添加子任务到 \"{task}\" ...",
+    "Add a task to \"{task}\"…" : "添加任务到 \"{task}\" ...",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n 任务完成"],
+    "Add an important task to \"{calendar}\"…" : "添加重要任务到 \"{calendar}\" ...",
+    "Add a task due today to \"{calendar}\"…" : "添加今天截止的任务到 \"{calendar}\" ...",
+    "Add a current task to \"{calendar}\"…" : "添加当前任务到 \"{calendar}\" ...",
+    "Add a task to \"{calendar}\"…" : "添加任务到 \"{calendar}\" ...",
     "Tomorrow" : "明天",
     "Set start date" : "设置开始日期",
     "Set start time" : "设置开始时间",
@@ -84,9 +92,16 @@ OC.L10N.register(
     "[Was due yesterday at] LT" : "[已截止于昨天的] LT",
     "[Was due on] LL [at] LT" : "[已截止于] LL [的] LT",
     "No priority assigned" : "未设置优先级",
+    "Priority {priority}: high" : "优先级 {priority}：高",
+    "Priority {priority}: medium" : "优先级 {priority}：中",
+    "Priority {priority}: low" : "优先级 {priority}：低",
+    "{percent} % completed" : "{percent} % 已完成",
     "When shared show full event" : "共享时显示完整事件",
     "When shared show only busy" : "共享时仅显示进行中的事件",
     "When shared hide this event" : "共享时隐藏本事件",
+    "Completed {date}" : "完成日期 {date}",
+    "Created {date}" : "创建日期 {date}",
+    "Last modified {date}" : "上一次更改 {date}",
     "Edit" : "编辑",
     "Copy private link" : "复制私人链接",
     "Copied" : "已复制",
@@ -97,7 +112,9 @@ OC.L10N.register(
     "New List" : "新列表",
     "Calendar link copied to clipboard." : "日历链接已复制到剪贴板。",
     "Calendar link could not be copied to clipboard." : "日历链接无法复制到剪贴板。",
+    "The name \"{calendar}\" is already used." : "名称 \"{calendar}\" 已被使用。",
     "An empty name is not allowed." : "不允许使用空名称。",
+    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "此操作将删除日历\"{calendar}\"以及所有相应的事件和任务。",
     "_Shared with {num} entity_::_Shared with {num} entities_" : ["与 {num} 个实体共享"],
     "Settings" : "设置",
     "Default list" : "默认列表",
