@@ -23,12 +23,10 @@ OC.L10N.register(
     "Set due date" : "指定到期日",
     "All day" : "全天",
     "Task not found!" : "找不到任務!",
-    "%s %% completed" : "%s %% 完成",
     "Edit" : "編輯",
     "Download" : "下載",
     "Save" : "儲存",
     "New List" : "新列表",
-    "The name \"%s\" is already used." : "名稱 \"%s\" 已被使用.",
     "An empty name is not allowed." : "不允許空白的名稱.",
     "Settings" : "設定",
     "Hidden" : "隱藏",
