@@ -27,12 +27,33 @@ use OCP\IL10N;
 
 class CollectionsService {
 
+	/**
+	 * @var string
+	 */
 	private $userId;
+
+	/**
+	 * @var IL10N
+	 */
 	private $l10n;
+
+	/**
+	 * @var IConfig
+	 */
 	private $settings;
+
+	/**
+	 * @var string
+	 */
 	private $appName;
 
-	public function __construct($userId, IL10N $l10n, IConfig $settings, $appName) {
+	/**
+	 * @param string $userId
+	 * @param IL10N $l10n
+	 * @param IConfig $settings
+	 * @param string $appName
+	 */
+	public function __construct(string $userId, IL10N $l10n, IConfig $settings, string $appName) {
 		$this->userId = $userId;
 		$this->l10n = $l10n;
 		$this->settings = $settings;
@@ -40,40 +61,40 @@ class CollectionsService {
 	}
 
 	/**
-	 * get all collections
+	 * Get all collections
 	 *
 	 * @return array
 	 */
-	public function getAll() {
+	public function getAll():array {
 		$collections = array(
 			array(
 				'id' => "starred",
-				'displayname' => (string)$this->l10n->t('Important'),
+				'displayName' => (string)$this->l10n->t('Important'),
 				'show' => 2,
 				'icon' => 'icon-task-star'),
 			array(
 				'id' => "today",
-				'displayname' => (string)$this->l10n->t('Today'),
+				'displayName' => (string)$this->l10n->t('Today'),
 				'show' => 2,
 				'icon' => 'icon-calendar'),
 			array(
 				'id' => "week",
-				'displayname' => (string)$this->l10n->t('Week'),
+				'displayName' => (string)$this->l10n->t('Week'),
 				'show' => 2,
 				'icon' => 'icon-calendar'),
 			array(
 				'id' => "all",
-				'displayname' => (string)$this->l10n->t('All'),
+				'displayName' => (string)$this->l10n->t('All'),
 				'show' => 2,
 				'icon' => 'icon-all'),
 			array(
 				'id' => "current",
-				'displayname' => (string)$this->l10n->t('Current'),
+				'displayName' => (string)$this->l10n->t('Current'),
 				'show' => 2,
 				'icon' => 'icon-current'),
 			array(
 				'id' => "completed",
-				'displayname' => (string)$this->l10n->t('Completed'),
+				'displayName' => (string)$this->l10n->t('Completed'),
 				'show' => 2,
 				'icon' => 'icon-checkmark')
 		);
@@ -89,13 +110,13 @@ class CollectionsService {
 	}
 
 	/**
-	 * set the visibility of a collection by collectionID
+	 * Set the visibility of a collection by collectionID
 	 *
-	 * @param int $collectionID
+	 * @param string $collectionID
 	 * @param int $visibility
 	 * @return bool
 	 */
-	public function setVisibility($collectionID, $visibility){
+	public function setVisibility(string $collectionID, int $visibility):bool {
 		if (in_array($visibility, array(0,1,2))){
 			$this->settings->setUserValue($this->userId, $this->appName,'show_'.$collectionID,$visibility);
 		}
